@@ -12,7 +12,9 @@ import aws_cdk.aws_iam._jsii
 import aws_cdk.core._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-events", "1.49.0", __name__[0:-6], "aws-events@1.49.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-cdk/aws-events", "1.52.0", __name__[0:-6], "aws-events@1.52.0.jsii.tgz"
+)
 
 __all__ = [
     "__jsii_assembly__",
